intelmq.bots.collectors.rsync package — intelmq 2.3.3.alpha1 documentation

# intelmq.bots.collectors.rsync package

## Submodules

## intelmq.bots.collectors.rsync.collector_rsync module

`intelmq.bots.collectors.rsync.collector_rsync.` `BOT`

  alias of `intelmq.bots.collectors.rsync.collector_rsync.RsyncCollectorBot`

class `intelmq.bots.collectors.rsync.collector_rsync.` `RsyncCollectorBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.CollectorBot`

  `init`()
  `process`()

## Module contents